# MODULE[data]: site_administration_defaults - All platforms, part 1

# FUNCTION
# This file is used to provide a base configuration for Simeon.  It
# is loaded everytime Simeon is started up BEFORE a user's configuration
# is loaded.   It is a fatal error for Simeon to not correctly load this 
# file.  See also, documentation in sysdflt2.tcl.
# END FUNCTION

# NOTES
#
# For release 4.1.2, parts of this file have been moved to sysdflt2.tcl due
# to a file size limitation in the Win16 TCL interpreter.  See sysdflt2.tcl
# for more information.
#
# This file has two main uses: provide default information for user's so
# that they don't have to configure it themselves, and provide
# administrative configuration that cannot be overridden by the user.
#
# The file is a Tool Command Language (TCL) file that contains a set of
# "option" commands.  The "option" command is a Simeon extension to TCL
# that supports updating the content of the Simeon runtime option
# (configuration) database.  The file can contain any of the standard
# TCL commands and statements.
#
# Options are defined using the following syntax:
#
#  "option [-default | -permanent | -session] [-readonly] {name} [{value}]
#
# where arguments in the [] are optional, and arguments in {} are
# variables that are provided by you.  If just the option {name} is
# provide with no {value}, then value of the option is returned.  If the
# {name} and {value} are provided, then the value is stored in the
# runtime option database.
# 
# Options can be stored in one of three levels: default, permanent, and
# session.  When options are referenced in the repository, a session
# value is retrieved ahead of a permanent value, and a permanent value
# is retrieved ahead of a default value.  Therefore, a session value
# will "mask" a permanent value which will "mask" a default value.  Only
# permanent values are saved from the option database to the user's
# permanent option repository. If no level is specified the default
# is permanent.
# 
# Usually, an administrator will set all options defined in this 
# file to be level "default".   This will allow the user to define
# permanent and session options that will be used in preference to
# the default value.   If the administrator wants to make sure that
# a value is used no matter what, then the option can be set
# "readonly" which will keep any other value from being stored
# into the database for that option.   For example, message service
# definitions that the user wants to enforce would be made readonly,
# and any attempt by the user to delete the message service in
# Simeon would result in failure.
# 
# Some examples:
#
# option -default  MsgService.IDList "1 2"
# option -default -readonly MsgService.ms1.Name "Post Office"
# option -default MsgService.ms2.Name "News Stand"
#
# Setting these options would create two message services (only
# partially defined for the example) named "Post Office" and
# "News Stand".   The user would be allowed to delete or rename
# "News Stand", but they would not be able to do either to "Post
# Office".
#
# Site Defaults file sysdflt2.tcl:
#
# 2nd site defaults file has been created (sysdflt2.tcl) which 
# contains the Helper Applications and the Column Manager settings.
# (This was due to a 65K file size limitation for the TCL 
# interpreter on Win16)
#
# Installation data file install.dat:
#
# sysdflt.tcl looks for install.dat file in the Simeon program 
# directory which indicates the folder prefix/location setting. 
# This file will be created by the Simeon 4.1.2 installer on all 
# platforms and has the following format:
#
# guest=["yes" | "no"]
# server=["Default" | "Simeon IMAP4" | "Washington Berkeley" | 
# "Washington Black Box" | "Sun Solstice" | "VMS with PMDF" | 
# "Netscape"]
#
# guest indicates whether Simeon is to be configured for a guest 
# account on our demo server. This may be omitted if you are 
# creating this file manually.
#
# server indicates the  server type and may be one of the 7 
# settings shown. 
#
# Accessor functions:
#
# The following functions have been added to the TCL interpreter 
# for use in the sysdflt and startup TCL files:
#
# debug_trace        - writes string to the debug.txt file in the Simeon 
#                      user working directory
# change_debug_level - changes the debug level inside Simeon to 
#                      begin c-client logging immediately. This
#                      allows for the debugging of connection
#                      problems on startup
# note               - displays the string in a dialog with an OK button
# work_dir           - returns the full path to the Simeon user 
#                      working directory
# appl_dir           - returns the full path to the Simeon program directory
# install_datafile   - returns full path and filename of the install.dat
#                      file
# platform           - returns the OS platform as one of:
#                      "windows", "windows32", "mac", "motif"
# screen_size        - returns the dimensions of the workstation display
#                      (ie. "800 600", "640 480" etc.)
# demo_client        - returns "yes" if the software is the evaluation
#                      release, "no" otherwise
#
# END NOTES
#
# HISTORY
# IncrDev Dec  4, 1997 by ll: updated version number to 4.1.4
# IncrDev Oct 20, 1997 by ll: added missing option, Editor.WrapPaste
# IncrDev Sep 30, 1997 by ll: added Folder.EnableRemote, Folder.EnableLocal options
# IncrDev Sep 30, 1997 by ll: added AddrBook.EnableRemote, AddrBook.EnableLocal options
# IncrDev Sep 26, 1997 by ll: added AddrBook.SearchFlagDefault and AddrBook.LocationDefault
# IncrDev Sep 24, 1997 by ll: updated version number, put $guest tests back in
#                             for 4.1.3
# IncrDev Sep 15, 1997 by ll: replaced all tests of $demo with $guest as the
#                             demo_client routine does not work in 4.1.2.,
#                             always returns 'no'. This is fixed in 4.1.3.
# IncrDev Sep 09, 1997 by kew: implemented new default rules for draft and
#                              sentmail folders based on the guest variable.
# IncrDev Aug 18, 1997 by ll: added Mac/Motif General.Mobile option, it was
#                             missed when the files were merged
# Doc     Jul 15, 1997 by ll: added doc on canonical names for default folders
# IncrDev Jul 15, 1997 by ll: changed default specification for default folders
#                             to refer to MsgService.ms? options names rather
#                             than use literal strings
# IncrDev Jul 14, 1997 by ll: moved FONTS AND COLORS section to sysdflt2.tcl
# Doc     Jul 14, 1997 by ll: added more doc throughout, mostly for option
#                             value settings
# IncrDev Jul 14, 1997 by ll: added change_debug_level doc and call
# IncrDev Jul 11, 1997 by ll: added documentation on accessor functions to NOTES
#                             changed server initialization to "Default"
# IncrDev Jul 11, 1997 by ll: changed the Default folder prefix to 
#                             blank, to match previous sysdflt.tcl
# IncrDev Jul 11, 1997 by ll: added sysdflt_version variable
# IncrDev Jul 10, 1997 by ll: split this into a second file sysdflt2.tcl
#                             because this grew too big for win16
# IncrDev Jul 10, 1997 by ll: extensive changes to incorporate the
#                             install.dat file and to combine
#                             all sysdflt.{pltfrm} files into one
# IncrDev Jun 25, 1997 by ll: changed various option values from
#                             lowercase to capitalized
# IncrDev May 28, 1997 by jps: fixed Unix print command, added comment
# IncrDev May 13, 1997 by ll: added AUTHENTICATION section for Solstice
#                             and Netscape IMAP4 servers.
# IncrDev Mar 27, 1997 by ll: changed default for Viewer.ActionDelete
#                             from "next" to "Next" as "next" was not
#                             recognized
#                             modified search criteria for Read Receipts
#                             message group to contain "read receipt"
# IncrDev Mar 12, 1997 by ll: modified doc for TR subject option
# IncrDev Mar 12, 1997 by ll: added General.TroubleReportSubject option
# IncrDev Feb 28, 1996 by ll: replaced xterm -e vi with vi as default
#                             Text/Plain viewer for Unix. Command line
#                             arguments are not accepted yet
# IncrDev Feb 27, 1997 by ll: changed Post Office Folder Location and
#                             Folder Prefix defaults from "~/" to "" (blank)
# IncrDev Feb 27, 1997 by ll: modified trouble report address to point
#                             to eval
#                             commented out OutboxFolder
#                             added discussion on Next and Previous
#                             for ActionDelete options
# IncrDev Feb 10, 1997 by ll: revised doc in Trouble Report, removed
#                             beta address
# IncrDev Feb 10, 1997 by ll: expanded Folder Location/Prefix discussion
#                             removed old Logging options
# IncrDev Jan 21, 1997 by ll: changed ReadReceipt policy to "Prompt"
#                             added -default to SepPosn and Colman options
# IncrDev Jan 16, 1997 by ll: turned on Windows Helper App examples
# IncrDev Dec 23, 1996 by ll: added new options for 4.1
# IncrDev Nov 27, 1996 by kw: commented 2nd line of next comment (oops)
# IncrDev Nov 27, 1996 by kw: changed values of WinPosn defaults to resolve
#                             line 0 problem
# IncrDev Nov 21, 1996 by rr: added Options.MandatoryRemote to force
#                             IMSPlogins
# IncrDev Nov 13, 1996 by rr: added General.BetaAddress
# IncrDev Oct 24, 1996 by cy: added General.DeliveryRules
# IncrDev Aug  5, 1996 by ll: fixed option name for second message
#                             service port from ms1.Port to ms2.Port
# IncrDev May 13, 1996 by ll: updated Macintosh window positions.
# IncrDev May 13, 1996 by ll: changed Macintosh default fonts from 10 to
#                             9 point
# IncrDev May  6, 1996 by ll: commented out PageLayout.Footer option so that
#                             startup.tcl file can set it instead
# IncrDev May  1, 1996 by ll: change default MDI behavior to ON
# IncrDev Mar 19, 1996 by ll: changed drafts and sentmail to local
#                             changed save outgoing to false
#                             changed expand on send to OFF
# IncrDev Mar 14, 1996 by ll: added documentation and rearranged order
#                             to be more logical
# IncrDev Feb 29, 1996 by ll: move AddrBook.Hostname and
#                             General.DeliveryHost to the beginning of
#                             file to group them under the user startup
#                             questions
# IncrDev Feb 04, 1996 by rr: add ms windows mdi switch
# IncrDev Feb  1, 1996 by ll: added FolderLocation, modified FolderPrefix
# IncrDev Jan 24, 1996 by ll: added examples of viewers for all platforms
# IncrDev Jan 23, 1996 by ll: changed default port number for PassWord Mgr
#                             from 8001 to 8000 on recommendation from JP
# IncrDev Jan 15, 1996 by sh: added General.ReadReceiptPolicy admin option
# IncrDev Dec 28, 1995 by ll: added Macintosh specific defaults
# IncrDev Dec 18, 1995 by ll: updated for version 4.0
# Doc____ Oct 30, 1995 by sh: first cut of new documentation (rather poor)
# IncrDev Oct 30, 1995 by sh: added -default and -readonly support
# IncrDev Aug 28, 1995 by sh: updated for Capricorn release
# IncrDev Aug 4, 1995 by gc: updated for demo release
# IncrDev May 19, 1995 by sh: updated for 3.0.2 release
# END HISTORY

# SYSDFLT DEBUG LOGGING

# To turn on debug logging in this file set the following variable
# to "yes". All debug_trace stmts will be written to the debug.txt file
# in the Simeon working directory.

set sdlog "no"

# END SYSDFLT DEBUG LOGGING

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : begin"}

# To turn on c-client logging from this point on, uncomment the
# following line. This is equivalent to setting Log Detail to All
# and C-client as the Subsystem to Log under Tools->Options->Edit->Logging.
# This allows us to debug startup connection problems on a mandatory remote
# startup, or a restoration of the desktop on startup requiring a remote 
# connection.

#change_debug_level all 256

# SYSDFLT VERSION

# Version string for the sysdflt file. 

set sysdflt_version "4.1.4"
if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : Version $sysdflt_version"}

# END SYSDFLT VERSION

# PROCS

# Procedure definitions

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : PROCS"}

proc getInstallData {} {

   global guest
   global server
   global sdlog

   if {$sdlog == "yes"} {debug_trace "getInstallData : proc entry"}

   catch {set install_file [install_datafile]}
   if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : install_datafile = $install_file"}

# Read the file created by the install program to see if we
# are setting up a guest account and what to set the folder
# prefix to

   if {[file exists $install_file]} {  
      if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : Opening $install_file"}
      set f [open $install_file r]
      if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : Opened $install_file"}
      while {[gets $f line] >= 0} {
         if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : line = $line"}
	 regexp "(\[^=]+)=\"(\[^\"]+)" $line junk varkey varval
         if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : varkey is: $varkey, varval is: $varval"}
         if {$varkey == "guest"} {
            set guest $varval
            if {$sdlog == "yes"} {debug_trace "getInstallData : guest = $guest"}
         } elseif {$varkey == "server"} {
            set server $varval
            if {$sdlog == "yes"} {debug_trace "getInstallData : server = $server"}
         }
      }
      close $f
   } else {
      if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : $install_file does not exist"}
      set guest "no"
      set server "Default"
   }

   if {$sdlog == "yes"} {
      debug_trace "getInstallData : guest = $guest, server = $server"
      debug_trace "getInstallData : end"
   }

}

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END PROCS"}

# END PROCS

# INITIALIZATIONS

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : INITIALIZATIONS"}

# Call platform accessor function to set the platform variable.
# Can be one of "mac", "motif", "windows" or "windows32"

set pltfrm ""
catch {set pltfrm [platform]}
if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : Platform = $pltfrm"}

# Call demo_client accessor function to set the demo variable.
# setting will be "yes" or "no"

set demo ""
catch {set demo [demo_client]}
if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : Demo = $demo"}

# Call screen_size to give us the size of the current screen

set scrsize ""
catch {set scrsize [screen_size]}
if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : screen size = $scrsize"}

# Initialize the guest and server type variables in case
# there is no install.dat file

set guest "no"
set server "Default"

# Call getInstallData to read install.dat

getInstallData 

if {$sdlog == "yes"} {
   debug_trace "sysdflt.tcl : Guest = $guest"
   debug_trace "sysdflt.tcl : server Type = $server"
}

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END INITIALIZATIONS"}

# END INITIALIZATIONS

# STARTUP DEFAULTS

# Defaults for the new user startup dialog (startup.tcl)

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : STARTUP DEFAULTS"}

# Mail domain will be defaulted into the email address question on startup
# If this field contained "simeon.com" then the user would see "@simeon.com"
# when prompted for his email address.
# If a guest account requested, set the mail domain to ESYS
# demo server
#

if {$guest == "no"} {
option -default General.MailDomain ""
} else {
option -default General.MailDomain "demo.simeon.com"
}

# This specifies the preferred machine used to send new mail messages.
# It should be running an SMTP server.
# By default, the startup.tcl file prompts the user for the SMTP
# hostname (proc verifySMTPHost). It uses the value here as the default
# prompt.
# If the hostname value here is correct and does need to be modified by the
# user, the startup question can be omitted. See startup.tcl for more
# information.

#
# If a guest account requested, set delivery host to ESYS demo server
#
if {$guest == "no"} {
option -default General.DeliveryHost "mailhost"
} else {
option -default General.DeliveryHost "\[198.161.92.131\]"
}

# Delivery (SMTP) host TCP port number. By default, the user is not prompted
# for this information from startup.tcl

option -default Send.TCPPort "25"

# Address book information can be held in an IMSP database.  The
# hostname for the server may be specified here. This should be the
# host name of an IMSP server on which users have valid accounts.
# By default this is empty  because a value in this field indicates
# to Simeon that an IMSP host is available and Simeon will search for
# remote address books when the address book module is started up.
# Leaving this field blank will cause Simeon to skip the remote book
# search and search for local books only.
# If the addressbook host name is set here and does not need to be
# changed by the user, you can remove the Address book prompt from the
# startup.tcl file. See startup.tcl for more information.

#
# If a guest account requested, set address book host to ESYS demo server
#
if {$guest == "no"} {
option -default AddrBook.Hostname ""
} else {
option -default AddrBook.Hostname "\[198.161.92.131\]"
}

# Address Book (IMSP) host TCP port number. By default, the user is not
# prompted for this information from startup.tcl

option -default AddrBook.TCPPort "406"

# : Default the IMSP options hostname to that given for the Address book
# : with the assumption that the the same IMSP host will be used for both.
# : If no IMSP host then these options will just be blank.

option -default Options.RemoteHost [option AddrBook.Hostname]
option -default Options.RemotePort [option AddrBook.TCPPort]

# This enables the site administrator to FORCE IMSP authenticated logins
# to the IMSP server. Simeon will exit if the login fails. This
# functions across all platforms.
# The default is not to require a remote IMSP login on startup.
#
# NOTE: Do not set this to TRUE unless the RemoteHost and RemotePort
# have been set here in the sysdflt.tcl file. Simeon must read the
# hostname and port from here in order to be able to force a first-time
# login to IMSP.

option -session Options.MandatoryRemote "FALSE"

# This specifies whether the user will be using delivery rules
# with Simeon.  User must have IMSP running. This option is not
# yet in use. Please leave set to FALSE.

option -default General.DeliveryRules "FALSE"

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END STARTUP DEFAULTS"}

# END STARTUP DEFAULTS


# MESSAGE SERVICES

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : MESSAGE SERVICES"}

# A message service is the entity which allows you to access your
# inbox and other mail folders. 
# There are three defined here, a Post Office, a News Stand
# and a local message service.
#
# For each message services specify the following:
#
#   - Name (user friendly name of the message service)
#   - Type (mail,bboard, or local)
#   - Hostname (the host running the IMAP server,n/a for local)
#   - Port (IMAP port number, defaults to 143)
#   - Folder Prefix
#     Used when creating new folders.  This represents where a 
#     new folder is to be created within the Message Service. 
#     With respect to the Simeon IMAP4 server, 'INBOX.' is 
#     equivalent to 'user.{username}.'
#   - Folder Location
#     Folder Location tells Simeon where in the Message Service 
#     to find the folders to display.  This may be a comma 
#     delimited list of several locations.
#
#
#   - Userid (userid to use to connect, will prompt if omitted)
#

#
# Header to indicate the number of message services defined.
#
option MsgService.IDList "1 2 3"

#
# IMAP Mail Message Service
#
option MsgService.ms1.Name "Post Office"
option MsgService.ms1.Type "mail"

# By default, the startup.tcl file prompts the user for the Post Office
# hostname (proc verifyMailHost). It uses the value here as the default
# for the display.
# If the hostname value here is correct and does need to be modified by the
# user, the startup question can be omitted. See startup.tcl for more
# information.

#
# If a guest account requested, set post office host to ESYS demo server
#
if {$guest == "no"} {
if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : setting default hostname"}
option MsgService.ms1.Hostname "mailhost"
} else {
# If the install program has indicated that the user wishes a guest account
# we point the message service to our demo server.
if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : setting hostname for demo server"}
option MsgService.ms1.Hostname "\[198.161.92.131\]"
}

#
#      The Folder Prefix and Location fields exist in Simeon
#      because of the varying nature of the 'personal' and 'group'
#      namespaces in the different IMAP servers.  Typically, the
#      actual format and location of mail messages and mail
#      folders on the server is very non-intuitive to the average
#      mail user.  Simeon uses the Folder Prefix and Location
#      fields to represent the user's mail folders in a uniform
#      and consisent manner regardless of the underlying
#      configuration supported by the IMAP server.
#
#      In reference to the Simeon IMAP4 server the default settings
#      represent the following:
#
#      'INBOX.' - find all of the user's folders in the user's 
#                 name space i.e. user.{username}.  If INBOX. is
#                 not specified, you will only see your inbox 
#                 (incoming mail) folder and none of your
#                 personally created folders.
#
#      'user.'  - find all other users' folders to which
#                 the user has been granted permission.  If user.
#                 is not specified you will only be able to see
#                 your own folders and no folders owned by others
#                 to which you have been given permission.
#
#      The strings in this field are also stripped from the 
#      Message Organizer display in order to make the folder list 
#      'flatter' by one level.  You can see this by removing both
#      INBOX. and user. from the Folder Location.  This results in 
#      2 folders at the top level: 'inbox' and 'user'. Under inbox 
#      you will find all of your incoming mail as well as your 
#      personally created folders, displayed as subfolders (This 
#      very closely resembles how the mail is actually stored on 
#      the server.)
#      The 'user' folder will contain the top-level list of other 
#      users' folders to which you have permission. 
#      
#     See the following for the common settings for Folder 
#     Prefix and Folder Location based on IMAP server type:
#     $server is set via the install program in install.tcl

if {$server == "Washington Berkeley" } {

option MsgService.ms1.FolderPrefix "~/Mail/"
option MsgService.ms1.FolderLocation "~/Mail/"

} elseif {$server == "Washington Black Box" } {

option MsgService.ms1.FolderPrefix "~/"
option MsgService.ms1.FolderLocation "~/"

} elseif {$server == "Default"} {

# This option is taken when the user chooses the default folder
# prefix during the install. Change these to the default for your
# site.

option MsgService.ms1.FolderPrefix ""
option MsgService.ms1.FolderLocation ""

} elseif {$server == "Simeon IMAP4"} {

option MsgService.ms1.FolderPrefix "INBOX."
option MsgService.ms1.FolderLocation "INBOX.,user."

} elseif {$server == "Sun Solstice"} {

option MsgService.ms1.FolderPrefix ""
option MsgService.ms1.FolderLocation ""

} elseif {$server == "Netscape"} {

option MsgService.ms1.FolderPrefix ""
option MsgService.ms1.FolderLocation ""

} elseif {$server == "VMS with PMDF"} {

option MsgService.ms1.FolderPrefix ""
option MsgService.ms1.FolderLocation ""

} else {
# Unknown server type, leave them blank

option MsgService.ms1.FolderPrefix ""
option MsgService.ms1.FolderLocation ""
} 

option MsgService.ms1.Port "143"
option MsgService.ms1.Userid ""

#
# IMAP News Message Service
#
option MsgService.ms2.Name "News Stand"
option MsgService.ms2.Type "bboard"
#
# If the install program indicates that the user wishes a guest
# account, we set it up to point to our demo server

if {$guest == "no"} {
option MsgService.ms2.Hostname "newshost"
} else {
option MsgService.ms2.Hostname "\[198.161.92.131\]"
}

option MsgService.ms2.Port "143"
option MsgService.ms2.FolderPrefix ""

# Select the newsgroups that you want included in subscription lists

option MsgService.ms2.FolderLocation "ab,can,comp,edm,gnu"
option MsgService.ms2.Userid ""

#
# LOCAL Mail Message Service
#
option MsgService.ms3.Name "Local Folders"
option MsgService.ms3.Type "local"
option MsgService.ms3.Hostname "Local Workstation"
option MsgService.ms3.FolderPrefix ""

# If left blank (recommended) folder location will default to the Simeon
# user (working) directory

option MsgService.ms3.FolderLocation ""
option MsgService.ms3.Userid ""

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END MESSAGE SERVICES"}

# END MESSAGE SERVICES

# DEFAULT FOLDERS

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : DEFAULT FOLDERS"}

# Note: The following options are not available from the
# Tools->Options->Edit menu.
#
# These options indicate whether to allow the creation of 
# local and/or remote folders.
# If set to "TRUE" (default) the user will be allowed to create
# new folders at the specified location.
# Note that it is not an error for both to be set to "FALSE"
# as a site may wish users to have access to shared IMAP
# folders but at the same time, prevent them from
# creating their own new folders, either remotely or locally.
#
# Additional Note: If folders already exist at the location which
# is disabled, the user will be able to access those folders
# as they normally would. These options, when set to FALSE, merely
# prevent the creation of NEW folders at the location.

option -default Folders.EnableRemote "TRUE"
option -default Folders.EnableLocal  "TRUE"

# The syntax for the default folder option values is as follows:
#
# "{MsgServiceName}!{FolderPrefix}{FolderName}"
# 
# You can specify the name literally as shown in the following examples:
#
# Example 1: "Local Folders!outbox"
# Example 2: "Post Office!~/Mail/drafts"
# Example 3: "Post Office!INBOX.sentmail"
#
# or you can use the following syntax to refer to the MsgService.ms?. option values
# as they are defined above (recommended):
#
# Example 1: "[option MsgService.ms3.Name]![option MsgService.ms3.FolderPrefix]outbox"
# Example 2: "[option MsgService.ms1.Name]![option MsgService.ms1.FolderPrefix]drafts"
# Example 3: "[option MsgService.ms1.Name]![option MsgService.ms1.FolderPrefix]sentmail"
#
# Example 2 assumes that MsgService.ms1.FolderPrefix is set to "~/Mail/"
# and Example 3 assumes that MsgService.ms1.FolderPrefix is "INBOX."
#
# Drafts and Sentmail
#
# The 'drafts' folder is a folder designated to hold unfinished mail
# which has not yet been sent to the recipient. The user saves mail
# to the drafts folder by explicitly invoking the Save to Drafts option.
#
# The 'sentmail' folder is a folder designated to hold copies of mail which have been
# sent to the recipient. (Do not confuse this folder with the queued messages or 'outbox'
# folder discussed in the following section.) The user indicates that he wishes to
# keep a copy of mail sent via the Compose Options window or Tools->Options->Compose.
#
# By default, the drafts and sentmail folders are defined based on whether the guest variable
# is set to "yes" (remote) or not (local).
#
# To set the drafts and sentmail options to point to the local message service specified above,
# use ms3 as shown:

#option -default Compose.DraftFolder "[option MsgService.ms3.Name]![option MsgService.ms3.FolderPrefix]drafts"
#option -default Compose.SentmailFolder "[option MsgService.ms3.Name]![option MsgService.ms3.FolderPrefix]sentmail"

# Remote folder drafts and sentmail configuration
#
# An alternative is to simply place the mail folders directly in the
# the user's home directory on the server. ie. "~/drafts".
# This is especially useful on dedicated mail servers
# that run a "Black Box" message store -- where only mail folders are
# allowed on the server and there are no interactive user logins.
#
# To default the drafts and sentmail folders to the remote message service
# (Post Office) use ms1 as shown:

#option -default Compose.DraftFolder "[option MsgService.ms1.Name]![option MsgService.ms1.FolderPrefix]drafts"
#option -default Compose.SentmailFolder "[option MsgService.ms1.Name]![option MsgService.ms1.FolderPrefix]sentmail"

# Default configuration for drafts and sentmail configuration
#
# By default, a guest user will be have their draft and sentmail folders set
# set for the remote message service (on the server).  All others will have
# their draft and sentmail folders set for their local message service (in
# their working directory).  (The $guest variable is read from the install.dat file).
#
# To disable these defaults, comment out the following lines, and uncomment the
# above desired message service.

if { $guest == "yes" } {
option -default Compose.DraftFolder "[option MsgService.ms1.Name]![option MsgService.ms1.FolderPrefix]drafts"
option -default Compose.SentmailFolder "[option MsgService.ms1.Name]![option MsgService.ms1.FolderPrefix]sentmail"
} else {
option -default Compose.DraftFolder "[option MsgService.ms3.Name]![option MsgService.ms3.FolderPrefix]drafts"
option -default Compose.SentmailFolder "[option MsgService.ms3.Name]![option MsgService.ms3.FolderPrefix]sentmail"
}

# Outbox
#
# The 'outbox' or queued messages folder is where messages are put when using 
# background delivery or when sending mail in offline mode. The messages are
# placed in this folder until the user requests that they be sent. 
# Background delivery can be selected by the user as the default
# delivery mode, or it is automatically set if foreground delivery
# fails.  For this reason, the outbox folder must always be a local
# folder.
#
# This option has been commented out because it causes an error to be
# displayed at startup when it is defined and the outbox does not yet exist.
# This will be the case for any new user of Simeon.  Any previous user
# who has specified an outbox folder will have already have this
# option in their personal options file.

#option -default General.OutboxFolder "[option MsgService.ms3.Name]![option MsgService.ms3.FolderPrefix]outbox"

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END DEFAULT FOLDERS"}

# END DEFAULT FOLDERS

# AUTHENTICATION (Solstice and Netscape IMAP4 servers)

# Simeon 411 working with Solstice and Netscape IMAP4 servers requires
# disabling of the unsupported IMAP "AUTHENTICATE" command by
# setting the following option to "ON". This forces the Simeon client to 
# attempt the clear text userid/password LOGIN mechanism only.
#
# To disable Simeon from attempting to authenticate via the IMAP
# AUTHENTICATE command, set this option to "ON" (default).
#
# To allow Simeon to attempt the AUTHENTICATE command, set the
# option to "OFF".

option -default  General.NoIMAPAuth "ON"

# The following option allows the site administrator to configure
# Simeon so that it will not attempt a clear text userid/password
# LOGIN. If this option is set to "ON" it forces Simeon to make a
# connection via the IMAP AUTHENTICATE mechanism. If the IMAP
# AUTHENTICATE command fails, Simeon will NOT attempt the LOGIN
# command and the user will be unable to connect.
#
# To allow Simeon to attempt the clear text userid/password LOGIN
# command, set this option to "OFF" (default).
#
# To disable Simeon from attempting the clear text userid/password LOGIN
# set this option to "ON".

option -default General.NoIMAPLogin "OFF"

# NOTE:
# It is an error to set both of these options to "ON". This error will be
# reported when Simeon attempts to open an IMAP connection.

# END AUTHENTICATION

# MESSAGE GROUPS
# Message groups allow you to group messages in together based on
# criteria such as subject, author etc. They are specified on a
# per folder basis, identified by the Message Service number and
# the folder name.  You may want to define some default message groups
# if you feel it is appropriate for your users. When creating message
# groups, specify the following:
#
# Name    - Name of the group displayed in the folder
# Fields  - message header fields to match, valid values:
#           Subject    Reply-To
#           From       In-Reply-To
#           To         Recipient
#           Cc         All
# Pattern - pattern to match
#           *pattern* - Contains
#           *pattern  - Starts with
#           pattern*  - Ends with
#           pattern   - Is (exact match)
# Sort    - the order to sort the messages, valid values:
#           Most Recent Arrival
#           Least Recent Arrival
#           Most Recent Date Sent
#           Least Recent Date Sent
#           From
#           Subject
# Hide If Empty - whether to remove the group header from the display if
#                 it contains no messages.
#

# Header, to identify the number of message groups for the inbox folder
option MessageGroups.1.inbox.IDList "1 2"

option MessageGroups.1.inbox.1.Name "Phone Messages"
option MessageGroups.1.inbox.1.Fields "Subject"
option MessageGroups.1.inbox.1.Pattern "*Phone Message*"
option MessageGroups.1.inbox.1.Sort "Most Recent Arrival"
option MessageGroups.1.inbox.1.HideIfEmpty "OFF"

option MessageGroups.1.inbox.2.Name "Read Receipts"
option MessageGroups.1.inbox.2.Fields "Subject"
option MessageGroups.1.inbox.2.Pattern "*read receipt*"
option MessageGroups.1.inbox.2.Sort "Most Recent Arrival"
option MessageGroups.1.inbox.2.HideIfEmpty "OFF"

# END MESSAGE GROUPS

# WINDOW POSITIONS

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : WINDOW POSITIONS"}

# The {platform}Posn option tells Simeon the default location and size of
# the top level application windows.
#
# Syntax: Option {platform}Posn.{windowname}.Border "Left,Top,Right,Bottom"
# in pixels
# {platform} can be one of Win Mac or Mtf

#
# Macintosh Window positions
#
option -default MacPosn.AddrBook.Border "336 24 649 224 Norm"
option -default MacPosn.Compose.Border "64 84 535 398 Norm"
option -default MacPosn.Folder.Border "23 44 519 369 Norm"
option -default MacPosn.MsgSrv.Border "24 44 520 369 Norm"
option -default MacPosn.TopMS.Border "4 24 531 327 Norm"
option -default MacPosn.Viewer.Border "44 64 515 378 Norm"
option -default Macintosh.ScreenWin.Border "0 0 640 460 0 1"
#
# Windows window positions
#
if {$scrsize == "640 480"} {
option -default WinPosn.AddrBook.Border "219 31 579 177 Norm"
option -default WinPosn.Compose.Border "49 49 576 356 Norm"
option -default WinPosn.Folder.Border "182 23 598 373 Norm"
option -default WinPosn.MsgSrv.Border "24 46 587 362 Norm"
option -default WinPosn.TaskWin.Border "16 51 618 470 Norm"
option -default WinPosn.TopMS.Border "4 23 174 373 Norm"
option -default WinPosn.Viewer.Border "18 41 582 332 Norm"
option -default Windows.ScreenWin.Border "0 0 640 480 0 78"
} elseif {$scrsize == "800 600"} {
#
# Windows window positions 800x600
#
option -default WinPosn.AddrBook.Border "433 32 735 290 Norm"
option -default WinPosn.Compose.Border "30 48 585 445 Norm"
option -default WinPosn.Folder.Border "299 23 768 482 Norm"
option -default WinPosn.MsgSrv.Border "24 46 587 362 Norm"
option -default WinPosn.TaskWin.Border "16 51 789 579 Norm"
option -default WinPosn.TopMS.Border "4 23 292 482 Norm"
option -default WinPosn.Viewer.Border "16 35 617 429 Norm"
option -default Windows.ScreenWin.Border "0 0 800 600 0 78"
} else {
#
# Windows window positions 1024 x 768
#
option -default WinPosn.AddrBook.Border "433 32 735 290 Norm"
option -default WinPosn.Compose.Border "30 48 585 445 Norm"
option -default WinPosn.Folder.Border "299 23 768 482 Norm"
option -default WinPosn.MsgSrv.Border "24 46 587 362 Norm"
option -default WinPosn.TaskWin.Border "16 51 789 579 Norm"
option -default WinPosn.TopMS.Border "4 23 292 482 Norm"
option -default WinPosn.Viewer.Border "16 35 617 429 Norm"
option -default Windows.ScreenWin.Border "0 0 1024 768 0 78"
}
#
# Motif Window Positions
#
option -default MtfPosn.AddrBook.Border "176 95 686 300 Norm"
option -default MtfPosn.Compose.Border "70 117 598 432 Norm"
option -default MtfPosn.Folder.Border "28 77 646 394 Norm"
option -default MtfPosn.MsgSrv.Border "16 64 600 385 Norm"
option -default MtfPosn.TaskWin.Border "0 0 1024 768 Norm"
option -default MtfPosn.TopMS.Border "6 54 626 380 Norm"
option -default MtfPosn.Viewer.Border "50 95 585 412 Norm"

# These indicate the position of the header, body and attachment
# sections of the Compose and Viewer windows.
#
if {$pltfrm == "windows" || $pltfrm == "windows32"} {
option -default SepPosn.Compose1 "41 81 0"
option -default SepPosn.Compose2 "41 81 0"
option -default SepPosn.Viewer1  "23 80 0"
option -default SepPosn.Viewer2  "23 80 0"
} elseif {$pltfrm == "mac" } {
option -default SepPosn.Compose1 "35 70 0"
option -default SepPosn.Compose2 "35 70 0"
option -default SepPosn.Viewer1 "25 70 0"
option -default SepPosn.Viewer2 "25 70 0"
} else {
option -default SepPosn.Compose1 "21 0 0"
option -default SepPosn.Compose2 "21 70 0"
option -default SepPosn.Viewer1 "22 70 0"
option -default SepPosn.Viewer2 "22 70 0"
}

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END WINDOW POSITIONS"}

# END WINDOW POSITIONS

# DEFAULT DESKTOP

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : DEFAULT DESKTOP"}

# Save desktop state on exit so it can be restored on the next startup.
# This saves the current window sizes, positions and contents including
# the column manager settings. Valid settings are "ON" or "OFF".

if {$demo == "yes"} {
option -default Desktop.SaveDesktopOnExit "OFF"
} else {
option -default Desktop.SaveDesktopOnExit "ON"
}
# The SaveMsg option tells Simeon the default Windows and Message Groups 
# to open on start up. In this example, the Inbox will be opened in a 
# separate window with the Main message group expanded to show the
# messages within it. DO not enable this on the Motif platform as there
# is a bug on first time startup which disables the Message Organizer
# window.

if {$pltfrm != "motif"} {
option -default SaveMsg.1.ms "1"
option -default SaveMsg.1.folder ""
option -default SaveMsg.1.group "0"
option -default SaveMsg.1.state "EXPAND"

option -default SaveMsg.2.ms "1"
option -default SaveMsg.2.folder "inbox"
option -default SaveMsg.2.group "0"
option -default SaveMsg.2.state "OPEN"

option -default SaveMsg.3.ms "1"
option -default SaveMsg.3.folder "inbox"
option -default SaveMsg.3.group "-1"
option -default SaveMsg.3.state "EXPAND"

option -default SaveMsg.4.ms "-1"
option -default SaveMsg.4.folder ""
option -default SaveMsg.4.group "0"
option -default SaveMsg.4.state "DONE"
} else {
option -default SaveMsg.1.ms "-1"
option -default SaveMsg.1.folder ""
option -default SaveMsg.1.group "0"
option -default SaveMsg.1.state "DONE"
}

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END DEFAULT DESKTOP"}

# END DEFAULT DESKTOP

# WINDOWS MDI BEHAVIOR

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : WINDOWS MDI BEHAVIOR"}

# MS Windows MDI window inheritance behavior. ON means that when a
# window is maximized and then closed the window gaining the focus is
# also maximized. (this is default Windows behavior)
# OFF means that when a maximized window is closed the window gaining
# the focus remains normalized.

if {$demo == "yes"} {
option -default Windows.MDI.Behavior "OFF"
} else {
option -default Windows.MDI.Behavior "ON"
}

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END WINDOWS MDI BEHAVIOR"}

# END WINDOWS MDI BEHAVIOR

# MAC AND MOTIF ONLINE/OFFLINE OPERATION

# Setting the following session option to "ON" will allow Mac and Motif
# clients to bring up the Online/Offline dialog at startup.
# The default of "OFF" suppresses the display of this dialog.

option -session General.Mobile "OFF"

# END MAC AND MOTIF ONLINE/OFFLINE OPERATION

# PASSWORD MANAGER
#
# The following options dictate whether the user will be allowed
# to change his password on the host from Simeon.

# TRUE enables the menu option FALSE disables it.
#
# Note: It should only be set to TRUE if you have
# the Simeon password manager daemon running on your server.

option -default -readonly General.PasswordManager.Enable "FALSE"

# The port number where the password manager daemon is running
# You may enter one option for each server running the password
# manager daemon or just set the default if they are all the same
#
# syntax: General.PasswordManager.port.{hostname} portnumber
#
# {hostname} = default means use this as the default for all hosts
#

option -default -readonly General.PasswordManager.port.default "1024"

#
# Examples of specific hostname port options
#
#option -default -readonly General.PasswordManager.port.monet   "1020"
#option -default -readonly General.PasswordManager.port.picasso "1022"

# END PASSWORD MANAGER

# READ RECEIPT POLICY
#
# This specifies the policy for generating read receipts (acknowledgements)
# It should be one of the following:
#  never  - never generatate a read receipt when requested (ignore request)
#  always - generate a read receipt when requested
#  prompt - ask user whether to generate the read receipt when requested
# Note: This option is not available for edit from Tools->Options->Edit

option -default -readonly General.ReadReceiptPolicy "Prompt"

# END READ RECEIPT POLICY

# VIEW MENU SETTINGS

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : VIEW MENU SETTINGS"}

# Setting to view short or raw messages headers when viewing a
# message in the Viewer window. Valid settings:
# "short" - Display selected formatted headers
# "raw"   - Display all headers as they appear in the RFC822 message envelope

option -default Viewer.HeaderStyle "short"

# Viewing hidden (empty) message groups is turned off by default. If user is upgrading
# from a previous version, the message group setting in his personal options
# will override this setting. Valid settings are
# "ON"  - view all message groups
# "OFF" - do not view hidden messages groups

option -default View.HiddenMsgGroups "OFF"

# Whether to view unsubscribed folders. Settings are:
# "ON"  - all folders will be displayed in the Message Organizer window
# "OFF" - only subscribed folders will be displayed in the MEssage Organizer window

option -default View.Unsubscribed "ON"

# Whether to display people and or lists in the Address Book Organizer
# window. Valid setting are "ON" or "OFF".

option -default AddrBook.ShowLists "ON"
option -default AddrBook.ShowPeople "ON"

# Whether Column Manager is displayed. Valid settings are "ON" or "OFF".

if { $demo == "yes"} {
option -default desktop.colman.visible "ON"
} else {
option -default desktop.colman.visible "OFF"
}

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END VIEW MENU SETTINGS"}

# END VIEW MENU SETTINGS

# PRINTING

# Default page layout info for printing messages
# Valid variables are:
#
# $from  - from header
# $subj  - subject header
# $date  - date sent
# $pdate - print date
# $page  - page number

# The following creates a header of date left justified,
# subject right justified and a footer with a centered page number.
# Valid variables are:
# $from	 Prints the name and e-mail address of the individual sending the message
#        as it appears in the envelope section From: header
# $date  Prints the date the message was sent (message Date: header)
# $subj  Prints the subject of the message as it appears in the envelope
#        section Subject: header
# $pdate Prints the current date (printing date)
# $page  Prints page numbers
# Any variable or text can be positioned on the line using the following:
#
# l	The "l" character for left justified text
# c	The "c" for center text
# r	The "r" for right justified text

# The l, c or r must be preceded by a space and followed by a space except
# when it is the first character letter of the header or footer.
# Text placed in a header or footer must be enclosed in single quotes.
# If a single quote is required in the text, use two single quotes. For example:
# 'John''s Mail'

option -default PageLayout.Header "\$pdate r \$subj"
# See startup.tcl for page footer default setting

# option -default PageLayout.Footer "c 'Page:' \$page"

# This option is not yet in use. Use $page to include a page
# number in a header or footer.
option -default PageLayout.PageNumbers "FALSE"

# Top and bottom margins are expressed in units of 'lines'

option -default PageLayout.TopMargin "5"
option -default PageLayout.BottomMargin "5"

# Left and right margins are expressed in units of 'characters' (actual
# width will depend on print font used)

option -default PageLayout.LeftMargin "5"
option -default PageLayout.RightMargin "5"

# Unix command used to send print output file to printer
# Simeon will replace the FIRST occurance of * with the name of the
# message file it wants to print

option -default Print.UnixCommand "lp *"

# END PRINTING

# USER

# See startup.tcl for General.FullName setting

# See startup.tcl for General.MailAddress setting

# See startup.tcl for General.ReplyTo setting

# See startup.tcl for default signature setting.

# Boolean to indicate whether to save userid/password to
# local file for auto start up. Defaulted to off as this
# is very insecure. To enabled this option, set to "TRUE".

option -default Options.SaveAuthInfo "FALSE"

# END USER

# MESSAGE ORGANIZER

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : MESSAGE ORGANIZER"}

# Check for new mail. Value is in minutes.

option -default Timer.Interval "10"

# Whether to clean (expunge messages marked for deletion) in open folders
# (mailboxes) on exit. Values are:
# "Always" - always clean mailboxes on exit
# "Never"  - never clean mailboxes on exit
# "Prompt" - when exiting, ask whether to clean mailboxes or not

option -default General.ExitClean "Prompt"

# When a message is deleted in the Message Organizer,
# specify whether the selection moves to the "Next" or 
# "Previous" message in the display.
#
# Please note that this option dictates Simeon's behaviour when
# a message is deleted while the focus is the Message Organizer window.
# This is different than Viewer.ActionDelete which controls the 
# selection when the focus is in the Viewer window.
#
# Also note that "Next" always means to move down the display,
# regardless of the sort order of the messages.  If your messages
# are sorted so that the most recently received one is at the top 
# "Next" will move the selection in a downward direction and give you the
# message listed below the current one.  In this case, the message will be
# older than the one currently selected. If you wish to process your
# mail in the order it was received, you would want to set this option
# to "Previous". 

option -default General.ActionDelete "Next"

# Fetch priority info off by default as this affects performance
# when loading folders. Values are "ON" or "OFF".
# It is on for the demo clients because we want them to see how it works.

if {$demo == "yes" } {
option -default General.PriorityHeader.Info "ON"
} else {
option -default General.PriorityHeader.Info "OFF"
}

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END MESSAGE ORGANIZER"}

# END MESSAGE ORGANIZER

# COMPOSE

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : COMPOSE"}

# LineWrap setting is in characters. The default line wrap setting fits nicely
# within the default compose window size.

if {$pltfrm == "windows" || $pltfrm == "windows32"} {
option -default Compose.LineWrap "60"
} else {
option -default Compose.LineWrap "72"
}

# Message Priority. If Fetch Priority Headers is on (General.PriorityHeader.Info "ON")
# in the recipient's Simeon configuration, the message will be displayed in the recipient's
# inbox with the corresponding fonts and colors as specified under the recipient's FONTS AND COLORS
# settings.
# Choices are
# "Normal" - message marked as normal priority (PRIORITY: NORMAL header in message envelope)
# "High"   - message contains header PRIORITY: URGENT
# "Low"    - message contains header PRIORITY: LOW

option -default Compose.Priority "Normal"

# Request delivery receipt. If requested, and the recipient's MTA supports this
# functionality, the recipient's MTA will send a confirmation back to the send 
# when the message is received into the recipient's inbox. Settings are:
# "TRUE" - send a delivery reciept to sender
# "FALSE" - do not send a delivery receipt to the sender

option -default Compose.RequestDeliveryRcpt "FALSE"

# Request read receipt. A read receipt is sent by Simeon when the recipient
# views the message in his inbox. Settings are:
# "TRUE"  - send a read receipt to the sender
# "FALSE" - do not send a read receipt to the sender

option -default Compose.RequestReadRcpt "FALSE"

# Save message to sentmail folder. 
# Settings are:
# "TRUE" - always save a copy of the sent message in the sentmail folder
# "FALSE" - do not save a copy of the sent message

option -default Compose.SaveOutgoing "FALSE"

# Whether to queue outgoing messages. This feature is most often used when
# working offline. When set to "TRUE" all composed messages are stored in the
# user's 'outbox' until such time as the user requests them to be sent.
# Settings are:
# "TRUE"  - queue all outgoing messages to the outbox until specifically requested
#           to send to the server
# "FALSE" - do not queue message, send to server immediately

option -default Compose.QueueOutgoing "FALSE"

# See DEFAULT FOLDERS section for the default settings for
# Sentmail and Drafts folders

# What to do with the Compose window after sending. Options are:
# "Close"  - close the window after sending is complete (default)
# "Clear"  - clear but do not close window after sending
# "Remain" - leave the compose window untouched after sending

option -default Compose.Disposition "Close"

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END COMPOSE"}

# END COMPOSE

# EDITOR

# External editor specification. Specification  does not need to contain full
# path if application in program path.

option -default Editor.Win.ExternalEditor "notepad.exe"
option -default Editor.Mac.ExternalEditor "SimpleText"
option -default Editor.Mtf.ExternalEditor "xterm -e vi"

# Whether to use an editor other than Simeon's when composing a message.
# "TRUE"  -  always use an external editor when Composing,
# "FALSE" -  do not use an external editor by default.

option -default Editor.Use.ExternalEditor "FALSE"

# URL Browser specification. Specification  does not need to contain full
# path if application in program path.

option -default Editor.Win.Browser "netscape.exe"
option -default Editor.Mac.Browser ""
option -default Editor.Mtf.Browser ""

# Setting to launch URL on dbl-click of URL in editor window
# Values are:
# "Always" - always launch browser on dbl-click
# "Prompt" - ask user if they want to launch a browser
# "Never"  - never launch browser, ignore dbl-click

option -default Editor.LaunchURL "Prompt"

# Whether to wrap text when pasted into a Compose edit session.
# "Never" will leave the pasted text alone, "Always" will wrap
# the pasted text to conform to the current linewrap setting.

option -default Editor.WrapPaste "Never"

# END EDITOR

# REPLY

# Whether to include all receipts in reply. (From, Cc)
# Valid settings are:
# "Always" - always include all recipients in response
# "Prompt" - ask user whether to include all recipients
# "Never"  - never include all recipients, use the From: field only

option -default Reply.All "Prompt"

# Whether to include original text in  reply. Values are:
# "Always" - alway include original text
# "Prompt" - ask user whether to include original text
# "Never"  - never include original text

option -default Reply.Text "Always"

# Indicates whether to wrap original text on a reply message.
# "TRUE"  - means always re-wrap on reply
# "FALSE" - means never re-wrap

option -default Reply.WrapOriginalText "FALSE"

# Character used to prefix original text in a reply. Can be any character.

option -default Reply.OriginalTextPrefix "> "

# Prefix inserted into the subject of a reply message

option -default Reply.Subject.Prefix "Re"

# END REPLY

# FORWARD

# Whether to forward the message as an RFC822 attachment vs. body text.
# Settings are:
# "Always" - always forward messages as an RFC822 attachment
# "Prompt" - ask user whether messages is to be forwarded as RFC822 attachment
# "Never" - never forward message as an RFC822 attachment, put original message
#          in the body of message

option -default Forward.Attachment "Prompt"

# Whether to wrap original text on forward.
# "TRUE"  - always re-wrap text to user's linewrap setting
# "FALSE" - do not re-wrap, leave original text untouched.

option -default Forward.WrapOriginalText "FALSE"

# Substring to use in subject on a fowarded message. Setting can be
# any sequence of characters.

option -default Forward.Subject.Prefix "fwd"

# Specification for the location of the forward subject substring.
# Values are:
# "Prefix" - insert forward subject string before subject
# "Suffix" - insert forward subject string after subject

option -default Forward.Subject.Location "Suffix"

# END FORWARD

# SEND

# See STARTUP DEFAULTS for default settings of SMTP hostname and port number.

# Expand addresses on send default to off. To turn it on use "ON"

option -default AddrBook.ExpandOnSend "OFF"

# This option is not available from the Tools->Options->Edit menu
# in Simeon. It dictates the type of search which will be performed
# in the address book when expanding an alias. The valid choices
# are "starts with", "contains","ends with", "is", (exact match)

option -default AddrBook.SearchType "starts with"

# What fields to search in the address book when expanding an
# alias. Settings are
# "ON"  - search this field
# "OFF" - do not search this field.

option -default AddrBook.SearchAlias "ON"
option -default AddrBook.SearchName "ON"
option -default AddrBook.SearchEmail "ON"

# Send method. Foreground or Background.
# Setting are:
# "ON"  - send messages in the background
# "OFF" - send messages in the foreground

option -default Send.Background "OFF"

# See DEFAULT FOLDERS for Queued Message Folder (outbox) default

# Option to disable the creation of a Sender header in mail generated by
# Simeon.  By default this option is FALSE and Sender headers ARE
# generated. Settings are:
# "FALSE" - do not suppress generation of sender header. Sender header will be generated
#           as follows
#           1. the value of the IMSP "common.from" variable.
#           2. the value of the session default userid specified in the login dialog,
#              concatenated with the domain specified in the IMSP option "common.domain" or,
#              if not available, the domain part of the user "From" address.
# "TRUE"  - suppress the generation of the sender header

option -default Send.SuppressSenderHeader "FALSE"

# END SEND

# VIEWER

# Option to indicate number of viewer windows allowed. Values are:
# "One"     - one viewer only, can only view one message at a time
# "Folder"  - one viewer per folder, can view one message per folder
#             at a time.
# "Message" - one viewer per message, ie. can view as many messages as
#             desired at one time

option -default Viewer.Instances "One"

# Whether to re-wrap message before viewing
# "Always" - always re-wrap to user's linewrap configuration
# "Never"  - never re-wrap, leave message as it was sent

option -default Viewer.AutoWrap "Never"

# What to do when you delete the message you are currently viewing.
# Choices are to view the "Next" or "Previous" message or "Close" the
# viewer window.
#
# Please note that this option dictates Simeon's behaviour when
# a message is deleted while the focus is in a Viewer window. This is
# different than the General.ActionDelete option, which controls the 
# selection when the focus is in the Message Organizer window.
#
# Please see MESSAGE ORGANIZER General.ActionDelete for a discussion
# on how Simeon interprets "Next" and "Previous".

option -default Viewer.ActionDelete "Next"

# END VIEWER

# ADDRESS BOOK

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : ADDRESS BOOK"}

# See STARTUP DEFAULTS for address book (IMSP) hostname and port number.

# Note: The following options are not available from the
# Tools->Options->Edit menu.
#
# These options indicate whether to allow the creation of 
# local and/or remote address books.
# If set to "TRUE" (default), the user will be allowed to create
# new address books at the specified location.
# Note that it is not an error for both to be set to "FALSE"
# as a site may wish users to have access to shared IMSP
# address books but at the same time, prevent them from
# creating their own new books, either remotely or locally.
#
# Additional Note: If books already exist at the location which
# is disabled, the user will be able to access those books
# as they normally would. These options, when set to FALSE, merely
# prevent the creation of NEW address books at the location.

option -default AddrBook.EnableRemote "TRUE"
option -default AddrBook.EnableLocal  "TRUE"

# Note: This option is not available from Tools->Options->Edit menu.
# It dictates the default setting for the "Search in Compose"
# setting in the New Address Book dialog.
# If set to "ON", Search in Compose will be checked by
# default, if set to "OFF", Search in Compose is not checked
# Note that this option does not prevent the user from
# changing the setting, it merely sets a policy for initializing
# the default.

option -default AddrBook.SearchFlagDefault "ON"

# Note: This option is not available from Tools->Options->Edit menu.
# It dictates the default setting for the address book location.
# (The "Remote and Local" radio buttons
# in the New Address Book dialog.)
# If set to "Remote", the Remote button will be selected.
# If set to "Local", the Local button will be selected.
# Note that this option does not prevent the user from
# changing the setting, it merely sets a policy for 
# initializing the default.

option -default AddrBook.LocationDefault "Local"

# The default host name and port number of the X.500 server.
# If a guest account requested, set LDUA host to ESYS demo server

if {$guest == "no"} {
option -default LDUA.Hostname ""
option -default LDUA.TCPPort "389"
} else {
option -default LDUA.Hostname "\[198.161.92.131\]"
option -default LDUA.TCPPort "389"
}

# Options controlling which attributes from person entries are
# save into the Simeon addressbook (These are not available for
# edit under Tools->Options->Edit)

option -default ldua.attribute_for_oid.rfc822Mailbox   "email"
option -default ldua.attribute_for_oid.streetAddress   "address"
option -default ldua.attribute_for_oid.telephoneNumber "phone"
option -default ldua.attribute_for_oid.favoriteDrink   "drink"
option -default ldua.attribute_for_oid.labeledURI      "home_page"

# also include shortname equivalents
option -default ldua.attribute_for_oid.mail            "email"
option -default ldua.attribute_for_oid.drink           "drink"
option -default ldua.attribute_for_oid.phone           "phone"
option -default ldua.attribute_for_oid.street          "address"

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END ADDRESSBOOK"}

# END ADDRESS BOOK

# ALIAS EXPANSION

# This turns on the Book search flag for the local address
# book so that there is at least one book for the alias
# expansion to work against. 

option -default AddrBook.SearchFlag.local "ON"

# If you wish to turn on the Search flag for a globally shared IMSP book
# uncomment the following and modify the book name appropriately.
# For instance, if the userid ubk4 owns a shared IMSP book called Staff
# the entry would be as shown below:

#option -default AddrBook.SearchFlag.ubk4.Staff "ON"

# END ALIAS EXPANSION

# LOGGING

# These options indicate whether to generate debug telemetry files
# while executing Simeon. The default should always be off unless
# trouble-shooting. These can be changed on the fly via 
# Tools->Options->Edit->Logging when running Simeon or in the
# DEBUG LOGGING section of this file. They are included here for
# documentation purposes.

option -default Debugging.Level "none"
option -default Debugging.Subsystem 0

# END LOGGING

# TROUBLE REPORT

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : TROUBLE REPORT"}

# This address is placed in the "To:" field of a Compose window when a
# user chooses "Compose->Trouble Report" from the main menu.  The intent
# is that site administrators will edit this field to contain the
# mail address of their local help desk.  This allows local help desk
# staff to manage and qualify trouble reports before contacting
# Simeon Technical Support.
#
# If the trblrpt.txt file from the Simeon distribution is placed in the
# user's working directory, it will be automatically read into the
# Compose window when Compose->Trouble report is selected.
# For demo software, initialize to the eval address"

if {$guest == "no"} {
option -default General.BetaAddress ""
} else {
option -default General.BetaAddress "Evaluate Simeon <eval@esys.ca>"
}

# 
# The default Subject line of the Trouble Report contains the OS and
# Simeon version similar to the following:
#
# Win32, 4.1.1 Build (5), Crash/Bug/Unexpected/Wish, Title.
#
# The idea is that the user will edit this subject line to categorize
# the type of problem and replace the word 'Title' with a one line
# description of the nature of the problem.
# The default Subject can be replaced with a customized version specific
# to the site by uncommenting and modifing the following option:

#option -default General.TroubleReportSubject "HelpDesk Customized Subject"

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl : END TROUBLE REPORT"}

# END TROUBLE REPORT

if {$sdlog == "yes"} {debug_trace "sysdflt.tcl end"}

# END MODULE : site_administration_defaults - All platforms, part 1
