# MODULE[data]: site_administration_defaults - All platforms, part 2

# FUNCTION
# This file is used to provide a base configuration for Simeon.  It
# is loaded everytime Simeon is started up BEFORE a user's configuration
# is loaded. It is NOT an error for Simeon to fail to sucessfully load this
# file. (For backwards compatibility.)
# END FUNCTION

# NOTES
#
# For release 4.1.2, this file contains the HELPER APPLICATIONS,
# FONTS and COLORS and COLUMN MANAGER sections which used to be located in
# sysdflt.tcl.
# See sysdflt.tcl file for additional documentation.
#
# END NOTES

# HISTORY
# BugFix_ Dec  4, 1997 by ll: removed extra space from UnixExtensions "RTF "
#                             in Viewers.2
# IncrDev Jul 14, 1997 by ll: moved FONTS AND COLORS section to this file
#                             from sysdflt.tcl
# IncrDev Jul 14, 1997 by ll: documentation additions
# IncrDev Jul 11, 1997 by ll: added test for sysdflt_version to determine
#                             whether to read this file. 
# Created Jul 10, 1997 by ll: split sysdflt.tcl into a second part
#                             because the file was too large for the TCL
#                             interpreter on Win16
# END HISTORY

if {[info exists sysdflt_version] == 1} {

# proceed, sysdflt.tcl must be for 4.1.2 or later

if {$sdlog == "yes"} {debug_trace "sysdflt2.tcl : begin"}

# HELPER APPLICATIONS

if {$sdlog == "yes"} {debug_trace "sysdflt2.tcl : HELPER APPLICATIONS"}

# Preload a number of MIME type to application assocations.  Feel free
# to add or delete from this list however the easiest way to set these is
# to use the Simeon Helper Applications interface itself. Here's how:
# 
# 1. Start Simeon.
# 2. Select Tools->Options->Edit from the menu.
# 3. Click on the icon labelled Helper Applications.
# 4. Enter the desired Helper Application specifications.
#    (See the Simeon User's manual for more information on how to specify a
#     Helper Application.)
# 5. Once all the Helper Applications have been defined, select
#    Tools->Options->Save-As... from the menu and save to a local file.
# 6. Open the local options file saved in step 5 with a text editor and sort the
#    lines alphabetically.  (This makes it easier to copy all of the lines
#    pertaining to the helper applications at once.)
# 7. Copy all lines beginning with "option Viewers." to the sysdflt.tcl file.
# 
# DOCUMENTATION:
# -The MacCommand is actually a friendly name.  Simeon picks up this name via
#  the creator, if this fails, it then picks up the name in the MacCommand.
# -If Simeon cannot find a mime type or if the mime type is an application/octet-stream,
#  it tries to match the file extension (if one exists) with the extensions
#  in the WinCommand.
# 
# a list of all the defined helper apps

option -default Viewers.IDLIST "1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21"

# START DOCUMENTATION FOR HELPER APP ID = 1
# The name for this helper app, user defined
option -default Viewers.1.Name "Plain Text"

# The Windows command for this helper app
option -default Viewers.1.WinCommand "notepad.exe"

# The Unix command for this helper app
option -default Viewers.1.UnixCommand "xterm -e vi"

# Mac friendly name for the application, not required as fetched with the creator.
option -default Viewers.1.MacCommand "SimpleText"

# Mac creator that specifies the application to launch.
option -default Viewers.1.MacCreator "ttxt"

# Indicates a list of all mime types for this helper app (only one in this example)
option -default Viewers.1.MimeList "1"

# The name for the first mime type in this helper app
option -default Viewers.1.MimeType.1.Name "Text/Plain"

# The Windows file extensions for the first mime type in this helper app,
# if more than one extension, separate each extension with '/',
# for example: "txt/tmp/bak"
option -default Viewers.1.MimeType.1.WinExtensions "txt/tmp/bak"

# Unix file extension for the first mime type of this helper app
option -default Viewers.1.MimeType.1.UnixExtensions "tcl/txt/c"

# The Mac file type for first mime type in this helper app
option -default Viewers.1.MimeType.1.MacExtensions "TEXT"


# END DOCUMENTATION FOR HELPER APP EXAMPLE

option -default Viewers.2.Name "Rich Text Format"
option -default Viewers.2.WinCommand ""
option -default Viewers.2.UnixCommand ""
option -default Viewers.2.MacCommand "Word"
option -default Viewers.2.MacCreator "MSWD"
option -default Viewers.2.MimeList "1"
option -default Viewers.2.MimeType.1.Name "Application/rtf"
option -default Viewers.2.MimeType.1.WinExtensions "RTF"
option -default Viewers.2.MimeType.1.UnixExtensions "RTF"
option -default Viewers.2.MimeType.1.MacExtensions "RTF "

option -default Viewers.3.Name "Mac Write II"
option -default Viewers.3.WinCommand ""
option -default Viewers.3.UnixCommand ""
option -default Viewers.3.MacCommand "Mac Write II"
option -default Viewers.3.MacCreator "MWII"
option -default Viewers.3.MimeList "1"
option -default Viewers.3.MimeType.1.Name "Application/macwriteii"
option -default Viewers.3.MimeType.1.WinExtensions "RTF"
option -default Viewers.3.MimeType.1.UnixExtensions "RTF"
option -default Viewers.3.MimeType.1.MacExtensions "MW2D"

option -default Viewers.4.Name "Jpeg Images"
option -default Viewers.4.WinCommand ""
option -default Viewers.4.UnixCommand ""
option -default Viewers.4.MacCommand "JPEGView"
option -default Viewers.4.MacCreator "JVWR"
option -default Viewers.4.MimeList "1"
option -default Viewers.4.MimeType.1.Name "image/jpeg"
option -default Viewers.4.MimeType.1.WinExtensions "jpg"
option -default Viewers.4.MimeType.1.UnixExtensions "jpg"
option -default Viewers.4.MimeType.1.MacExtensions "JPEG"

option -default Viewers.5.Name "Gif Images"
option -default Viewers.5.WinCommand ""
option -default Viewers.5.UnixCommand ""
option -default Viewers.5.MacCommand "JPEGView"
option -default Viewers.5.MacCreator "JVWR"
option -default Viewers.5.MimeList "1"
option -default Viewers.5.MimeType.1.Name "image/gif"
option -default Viewers.5.MimeType.1.WinExtensions "gif"
option -default Viewers.5.MimeType.1.UnixExtensions "gif"
option -default Viewers.5.MimeType.1.MacExtensions "GIFf"

option -default Viewers.6.Name "Bitmap Images"
option -default Viewers.6.WinCommand "paintbrush.exe"
option -default Viewers.6.UnixCommand ""
option -default Viewers.6.MacCommand "JPEGView"
option -default Viewers.6.MacCreator "JVWR"
option -default Viewers.6.MimeList "1"
option -default Viewers.6.MimeType.1.Name "image/bitmap"
option -default Viewers.6.MimeType.1.WinExtensions "bmp"
option -default Viewers.6.MimeType.1.UnixExtensions "bmp"
option -default Viewers.6.MimeType.1.MacExtensions "BMPp"

option -default Viewers.7.Name "Tag Image Format"
option -default Viewers.7.WinCommand ""
option -default Viewers.7.UnixCommand ""
option -default Viewers.7.MacCommand "JPEGView"
option -default Viewers.7.MacCreator "JVWR"
option -default Viewers.7.MimeList "1"
option -default Viewers.7.MimeType.1.Name "image/tiff"
option -default Viewers.7.MimeType.1.WinExtensions "tif"
option -default Viewers.7.MimeType.1.UnixExtensions "tif"
option -default Viewers.7.MimeType.1.MacExtensions "TIFF"

option -default Viewers.8.Name "Audio Basic"
option -default Viewers.8.WinCommand ""
option -default Viewers.8.UnixCommand ""
option -default Viewers.8.MacCommand "SoundMachine"
option -default Viewers.8.MacCreator "SNDM"
option -default Viewers.8.MimeList "1"
option -default Viewers.8.MimeType.1.Name "audio/basic"
option -default Viewers.8.MimeType.1.WinExtensions "au"
option -default Viewers.8.MimeType.1.UnixExtensions "au"
option -default Viewers.8.MimeType.1.MacExtensions "ULAW"

option -default Viewers.9.Name "Audio Wave"
option -default Viewers.9.WinCommand ""
option -default Viewers.9.UnixCommand ""
option -default Viewers.9.MacCommand "SoundApp"
option -default Viewers.9.MacCreator "SCPL"
option -default Viewers.9.MimeList "1"
option -default Viewers.9.MimeType.1.Name "audio/wave"
option -default Viewers.9.MimeType.1.WinExtensions "wav"
option -default Viewers.9.MimeType.1.UnixExtensions "wav"
option -default Viewers.9.MimeType.1.MacExtensions "WAVE"

option -default Viewers.10.Name "Audio Voice"
option -default Viewers.10.WinCommand ""
option -default Viewers.10.UnixCommand ""
option -default Viewers.10.MacCommand "SoundApp"
option -default Viewers.10.MacCreator "SCPL"
option -default Viewers.10.MimeList "1"
option -default Viewers.10.MimeType.1.Name "audio/voice"
option -default Viewers.10.MimeType.1.WinExtensions "voc"
option -default Viewers.10.MimeType.1.UnixExtensions "voc"
option -default Viewers.10.MimeType.1.MacExtensions "VOC "

option -default Viewers.11.Name "Video Mpeg"
option -default Viewers.11.WinCommand ""
option -default Viewers.11.UnixCommand ""
option -default Viewers.11.MacCommand "Sparkle"
option -default Viewers.11.MacCreator "mMPG"
option -default Viewers.11.MimeList "1"
option -default Viewers.11.MimeType.1.Name "video/mpeg"
option -default Viewers.11.MimeType.1.WinExtensions "mpg"
option -default Viewers.11.MimeType.1.UnixExtensions "mpg"
option -default Viewers.11.MimeType.1.MacExtensions "MPEG"
#
option -default Viewers.12.Name "Video Quicktime"
option -default Viewers.12.WinCommand ""
option -default Viewers.12.UnixCommand ""
option -default Viewers.12.MacCommand "SimpleText"
option -default Viewers.12.MacCreator "ttxt"
option -default Viewers.12.MimeList "1"
option -default Viewers.12.MimeType.1.Name "video/quicktime"
option -default Viewers.12.MimeType.1.WinExtensions "mov"
option -default Viewers.12.MimeType.1.UnixExtensions "mov"
option -default Viewers.12.MimeType.1.MacExtensions "MooV"
#
option -default Viewers.13.Name "Mac PICT"
option -default Viewers.13.WinCommand ""
option -default Viewers.13.UnixCommand ""
option -default Viewers.13.MacCommand "SimpleText"
option -default Viewers.13.MacCreator "ttxt"
option -default Viewers.13.MimeList "1"
option -default Viewers.13.MimeType.1.Name "image/pict"
option -default Viewers.13.MimeType.1.WinExtensions "pic"
option -default Viewers.13.MimeType.1.UnixExtensions "pic"
option -default Viewers.13.MimeType.1.MacExtensions "PICT"
#
option -default Viewers.14.Name "Audio Aiff"
option -default Viewers.14.WinCommand ""
option -default Viewers.14.UnixCommand ""
option -default Viewers.14.MacCommand "SoundMachine"
option -default Viewers.14.MacCreator "SNDM"
option -default Viewers.14.MimeList "1"
option -default Viewers.14.MimeType.1.Name "audio/aiff"
option -default Viewers.14.MimeType.1.WinExtensions "aif"
option -default Viewers.14.MimeType.1.UnixExtensions "aif"
option -default Viewers.14.MimeType.1.MacExtensions "AIFF"
#
option -default Viewers.15.Name "Mac Binhex40"
option -default Viewers.15.WinCommand ""
option -default Viewers.15.UnixCommand ""
option -default Viewers.15.MacCommand "Stuffit Expander"
option -default Viewers.15.MacCreator "SITx"
option -default Viewers.15.MimeList "1"
option -default Viewers.15.MimeType.1.Name "application/mac-binhex40"
option -default Viewers.15.MimeType.1.WinExtensions "hqx"
option -default Viewers.15.MimeType.1.UnixExtensions "hqx"
option -default Viewers.15.MimeType.1.MacExtensions "disk"
#
option -default Viewers.16.Name "Mac Binary"
option -default Viewers.16.WinCommand ""
option -default Viewers.16.UnixCommand ""
option -default Viewers.16.MacCommand "Mac Binary II+"
option -default Viewers.16.MacCreator "MB2P"
option -default Viewers.16.MimeList "1"
option -default Viewers.16.MimeType.1.Name "application/x-macbinary"
option -default Viewers.16.MimeType.1.WinExtensions "bin"
option -default Viewers.16.MimeType.1.UnixExtensions "bin"
option -default Viewers.16.MimeType.1.MacExtensions "TEXT"
#
option -default Viewers.17.Name "Zip"
option -default Viewers.17.WinCommand "winzip.exe"
option -default Viewers.17.UnixCommand ""
option -default Viewers.17.MacCommand "ZipIt"
option -default Viewers.17.MacCreator "ZIP "
option -default Viewers.17.MimeList "1"
option -default Viewers.17.MimeType.1.Name "application/x-compressed"
option -default Viewers.17.MimeType.1.WinExtensions "zip"
option -default Viewers.17.MimeType.1.UnixExtensions "zip"
option -default Viewers.17.MimeType.1.MacExtensions "TEXT"
#
option -default Viewers.18.Name "Tar"
option -default Viewers.18.WinCommand ""
option -default Viewers.18.UnixCommand "tar"
option -default Viewers.18.MacCommand "SunTar"
option -default Viewers.18.MacCreator "S691"
option -default Viewers.18.MimeList "1"
option -default Viewers.18.MimeType.1.Name "application/x-tar"
option -default Viewers.18.MimeType.1.WinExtensions "tar"
option -default Viewers.18.MimeType.1.UnixExtensions "tar"
option -default Viewers.18.MimeType.1.MacExtensions "TARF"
#
option -default Viewers.19.Name "Microsoft Word 6"
option -default Viewers.19.WinCommand "winword.exe"
option -default Viewers.19.UnixCommand ""
option -default Viewers.19.MacCommand "Word"
option -default Viewers.19.MacCreator "MSWD"
option -default Viewers.19.MimeList "1"
option -default Viewers.19.MimeType.1.Name "application/msword"
option -default Viewers.19.MimeType.1.WinExtensions "doc"
option -default Viewers.19.MimeType.1.UnixExtensions "doc"
option -default Viewers.19.MimeType.1.MacExtensions "W6BN"
#
option -default Viewers.20.Name "Microsoft Excel 5"
option -default Viewers.20.WinCommand "excel.exe"
option -default Viewers.20.UnixCommand ""
option -default Viewers.20.MacCommand "Excel"
option -default Viewers.20.MacCreator "XCEL"
option -default Viewers.20.MimeList "1"
option -default Viewers.20.MimeType.1.Name "application/msexcel"
option -default Viewers.20.MimeType.1.WinExtensions "xls"
option -default Viewers.20.MimeType.1.UnixExtensions "xls"
option -default Viewers.20.MimeType.1.MacExtensions "XLS "

option -default Viewers.21.Name "Microsoft Power Point 3"
option -default Viewers.21.WinCommand ""
option -default Viewers.21.UnixCommand ""
option -default Viewers.21.MacCommand "PowerPoint"
option -default Viewers.21.MacCreator "PPT3"
option -default Viewers.21.MimeList "1"
option -default Viewers.21.MimeType.1.Name "application/powerpoint"
option -default Viewers.21.MimeType.1.WinExtensions "ppt"
option -default Viewers.21.MimeType.1.UnixExtensions "ppt"
option -default Viewers.21.MimeType.1.MacExtensions "SLD3"

if {$sdlog == "yes"} {debug_trace "sysdflt2.tcl : END HELPER APPLICATIONS"}

# END HELPER APPLICATIONS

# FONTS AND COLORS

if {$sdlog == "yes"} {debug_trace "sysdflt2.tcl : FONTS AND COLORS"}

# Simeon can be pre-configured with variety of different fonts and colors
# in any of the Window Objects:
#
# Address Book
# Address List
# Address Person
# Compose Editor
# Compose Headers
# Default
# Folder Subscribed
# Folder Unsubscribed
# Message Group
# Message High Priority
# Message Low Priority
# Message Normal Priority
# Message Service
# Print Message
# Search Object
# Viewer Editor
# Viewer Headers
#
# Color choices:
# Red,Green,Blue,Cyan,Magenta,Yellow,Black,Dark Grag,Gray,Light Gray,White

# Default colors for Macintosh

option -default Color.Mac.AddressBook "Black"
option -default Color.Mac.AddressList "Black"
option -default Color.Mac.AddressPerson "Black"
option -default Color.Mac.ComposeEditor "Black"
option -default Color.Mac.ComposeHeaders "Black"
option -default Color.Mac.Default "Black"
option -default Color.Mac.MessageGroup "Black"
option -default Color.Mac.MessageHigh "Red"
option -default Color.Mac.MessageLow "Gray"
option -default Color.Mac.MessageNormal "Black"
option -default Color.Mac.MessageService "Black"
option -default Color.Mac.PrintMsg "Black"
option -default Color.Mac.Search "Black"
option -default Color.Mac.SubscribedFolder "Black"
option -default Color.Mac.UnsubscribedFolder "Gray"
option -default Color.Mac.ViewerEditor "Black"
option -default Color.Mac.ViewerHeader "Black"

# Default colors for Windows

option -default Color.Windows.AddressBook "Black"
option -default Color.Windows.AddressList "Blue"
option -default Color.Windows.AddressPerson "Black"
option -default Color.Windows.ComposeEditor "Black"
option -default Color.Windows.ComposeHeaders "Black"
option -default Color.Windows.Default "Black"
option -default Color.Windows.MessageGroup "Black"
option -default Color.Windows.MessageHigh "Red"
option -default Color.Windows.MessageLow "Gray"
option -default Color.Windows.MessageNormal "Black"
option -default Color.Windows.MessageService "Blue"
option -default Color.Windows.PrintMsg "Black"
option -default Color.Windows.Search "Black"
option -default Color.Windows.SubscribedFolder "Black"
option -default Color.Windows.UnsubscribedFolder "Gray"
option -default Color.Windows.ViewerHeader "Black"
option -default Color.Windows.ViewerEditor "Black"

# Default colors for Motif

option -default Color.Motif.AddressBook "Black"
option -default Color.Motif.AddressList "Blue"
option -default Color.Motif.AddressPerson "Black"
option -default Color.Motif.ComposeEditor "Black"
option -default Color.Motif.ComposeHeaders "Black"
option -default Color.Motif.Default "Black"
option -default Color.Motif.MessageGroup "Black"
option -default Color.Motif.MessageHigh "Red"
option -default Color.Motif.MessageLow "Gray"
option -default Color.Motif.MessageNormal "Black"
option -default Color.Motif.MessageService "Blue"
option -default Color.Motif.PrintMsg "Black"
option -default Color.Motif.Search "Black"
option -default Color.Motif.SubscribedFolder "Black"
option -default Color.Motif.UnsubscribedFolder "Gray"
option -default Color.Motif.ViewerEditor "Black"
option -default Color.Motif.ViewerHeader "Black"

# Default fonts for Macintosh

option -default Font.Mac.AddressBook "01\\Geneva\\1\\9\\@"
option -default Font.Mac.AddressList "01\\Geneva\\1\\9\\@"
option -default Font.Mac.AddressPerson "01\\Geneva\\0\\9\\@"
option -default Font.Mac.ComposeEditor "01\\Monaco\\0\\9\\@"
option -default Font.Mac.ComposeHeaders "01\\Monaco\\0\\9\\@"
option -default Font.Mac.Default "01\\Geneva\\0\\9\\@"
option -default Font.Mac.MessageGroup "01\\Geneva\\2\\9\\@"
option -default Font.Mac.MessageHigh "01\\Geneva\\0\\9\\@"
option -default Font.Mac.MessageLow "01\\Geneva\\0\\9\\@"
option -default Font.Mac.MessageNormal "01\\Geneva\\0\\9\\@"
option -default Font.Mac.MessageService "01\\Geneva\\1\\9\\@"
option -default Font.Mac.PrintMsg "01\\Courier\\0\\9\\@"
option -default Font.Mac.Search "01\\Geneva\\1\\9\\@"
option -default Font.Mac.SubscribedFolder "01\\Geneva\\1\\9\\@"
option -default Font.Mac.UnsubscribedFolder "01\\Geneva\\1\\9\\@"
option -default Font.Mac.ViewerEditor "01\\Monaco\\0\\9\\@"
option -default Font.Mac.ViewerHeader "01\\Monaco\\1\\9\\@"

if {$pltfrm == "windows"} {

# Default fonts for 16 bit Windows

option -default Font.Windows.AddressBook "01\\MS Sans Serif\\0\\10\\WIN01/-13/0/0/0/400/0/0/0/0/1/2/1/34/MS Sans Serif"
option -default Font.Windows.AddressList "01\\Times New Roman\\0\\10\\WIN01/-13/0/0/0/400/0/0/0/0/3/2/1/18/Times New Roman"
option -default Font.Windows.AddressPerson "01\\Times New Roman\\0\\10\\WIN01/-13/0/0/0/400/0/0/0/0/3/2/1/18/Times New Roman"
option -default Font.Windows.ComposeEditor "01\\fixed\\0\\10\\(null)"
option -default Font.Windows.ComposeHeaders "01\\system\\0\\12\\(null)"
option -default Font.Windows.Default "01\\system\\0\\12\\(null)"
option -default Font.Windows.SubscribedFolder "01\\Times New Roman\\0\\12\\(null)"
option -default Font.Windows.UnsubscribedFolder "01\\Times New Roman\\0\\12\\(null)"
option -default Font.Windows.MessageGroup "01\\Times New Roman\\1\\12\\(null)"
option -default Font.Windows.MessageHigh "01\\system\\0\\12\\(null)"
option -default Font.Windows.MessageLow "01\\system\\0\\12\\(null)"
option -default Font.Windows.MessageNormal "01\\system\\0\\12\\(null)"
option -default Font.Windows.MessageService "01\\Times New Roman\\1\\12\\WIN01/-16/0/0/0/700/0/0/0/0/3/2/1/18/Times New Roman"
option -default Font.Windows.PrintMsg "01\\Times New Roman\\0\\10\\(null)"
option -default Font.Windows.Search "01\\Times New Roman\\1\\12\\WIN01/-16/0/0/0/700/0/0/0/0/3/2/1/18/Times New Roman"
option -default Font.Windows.ViewerEditor "01\\fixed\\0\\10\\(null)"
option -default Font.Windows.ViewerHeader "01\\system\\0\\12\\(null)"
} else {

# Default fonts for 32 bit Windows ("windows32")

option -default Font.Windows.AddressBook "01\\MS Sans Serif\\0\\10\\WIN01"
option -default Font.Windows.AddressList "01\\MS Sans Serif\\0\\10\\(null)"
option -default Font.Windows.AddressPerson "01\\MS Sans Serif\\0\\10\\(null)"
option -default Font.Windows.ComposeEditor "01\\fixed\\0\\10\\(null)"
option -default Font.Windows.ComposeHeaders "01\\MS Sans Serif\\0\\10\\(null)"
option -default Font.Windows.Default "01\\MS Sans Serif\\0\\10\\(null)"
option -default Font.Windows.MessageGroup "01\\MS Sans Serif\\1\\8\\(null)"
option -default Font.Windows.MessageHigh "01\\MS Sans Serif\\1\\8\\(null)"
option -default Font.Windows.MessageLow "01\\MS Sans Serif\\0\\8\\(null)"
option -default Font.Windows.MessageNormal "01\\MS Sans Serif\\1\\8\\(null)"
option -default Font.Windows.MessageService "01\\MS Sans Serif\\1\\10\\(null)"
option -default Font.Windows.PrintMsg "01\\Courier\\0\\10\\(null)"
option -default Font.Windows.Search "01\\MS Sans Serif\\0\\8\\(null)"
option -default Font.Windows.SubscribedFolder "01\\MS Sans Serif\\1\\8\\(null)"
option -default Font.Windows.UnsubscribedFolder "01\\MS Sans Serif\\0\\8\\(null)"
option -default Font.Windows.ViewerHeader "01\\fixed\\0\\10\\(null)"
option -default Font.Windows.ViewerEditor "01\\fixed\\0\\10\\(null)"
}

# Default fonts for Motif

option -default Font.Motif.AddressBook "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.AddressList "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.AddressPerson "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.ComposeEditor "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.ComposeHeaders "01\\system\\1\\12\\X1101/misc/fixed/bold/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.Default "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.SubscribedFolder "01\\system\\1\\12\\X1101/misc/fixed/bold/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.UnsubscribedFolder "01\\system\\1\\12\\X1101/misc/fixed/bold/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.MessageGroup "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.MessageHigh "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.MessageLow "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.MessageNormal "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.MessageService "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.PrintMsg "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.Search "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.ViewerEditor "01\\system\\0\\12\\X1101/misc/fixed/medium/r/normal//*/120/75/75/c/*/iso8859/1"
option -default Font.Motif.ViewerHeader "01\\system\\1\\12\\X1101/misc/fixed/bold/r/normal//*/120/75/75/c/*/iso8859/1"

if {$sdlog == "yes"} {debug_trace "sysdflt2.tcl : END FONTS AND COLORS"}

# END FONTS AND COLORS

# COLUMN MANAGER

if {$sdlog == "yes"} {debug_trace "sysdflt2.tcl : COLUMN MANAGER"}

# These settings have been preconfigured for each platform and under
# normal circumstances it is not necessary for them to be changed
# for the site configuration.
# If you wish to make changes, the easiest way is to run Simeon,
# make the desired changes and then save options (with Save Desktop on) to a
# .tcl file. Then copy all of the options prefixed with desktop.colman
# to this location.

# Whether the specified column in the display is visible or not.
# Values are "ON" to show the column, or "OFF" to hide it.

option -default desktop.colman.folder.Group.Count.visible "ON"
option -default desktop.colman.folder.Group.Icon.visible "ON"
option -default desktop.colman.folder.Group.Name.visible "ON"
option -default desktop.colman.folder.Message.Date.visible "ON"
option -default desktop.colman.folder.Message.From.visible "ON"
option -default desktop.colman.folder.Message.Icon.visible "ON"
option -default desktop.colman.folder.Message.Size.visible "ON"
option -default desktop.colman.folder.Message.Subject.visible "ON"
option -default desktop.colman.msgservice.Folder.Count.visible "ON"
option -default desktop.colman.msgservice.Folder.Icon.visible "ON"
option -default desktop.colman.msgservice.Folder.Name.visible "ON"
option -default desktop.colman.msgservice.Folder.RO.visible "ON"
option -default desktop.colman.msgservice.Group.Count.visible "ON"
option -default desktop.colman.msgservice.Group.Icon.visible "ON"
option -default desktop.colman.msgservice.Group.Name.visible "ON"
option -default desktop.colman.msgservice.Message.Date.visible "ON"
option -default desktop.colman.msgservice.Message.From.visible "ON"
option -default desktop.colman.msgservice.Message.Icon.visible "ON"
option -default desktop.colman.msgservice.Message.Size.visible "ON"
option -default desktop.colman.msgservice.Message.Subject.visible "ON"
option -default desktop.colman.topms.Folder.Count.visible "ON"
option -default desktop.colman.topms.Folder.Icon.visible "ON"
option -default desktop.colman.topms.Folder.Name.visible "ON"
option -default desktop.colman.topms.Folder.RO.visible "ON"
option -default desktop.colman.topms.Group.Count.visible "ON"
option -default desktop.colman.topms.Group.Icon.visible "ON"
option -default desktop.colman.topms.Group.Name.visible "ON"
option -default desktop.colman.topms.Message.Date.visible "ON"
option -default desktop.colman.topms.Message.From.visible "ON"
option -default desktop.colman.topms.Message.Icon.visible "ON"
option -default desktop.colman.topms.Message.Size.visible "ON"
option -default desktop.colman.topms.Message.Subject.visible "ON"
option -default desktop.colman.topms.MsgService.Icon.visible "ON"
option -default desktop.colman.topms.MsgService.Name.visible "ON"

if {$sdlog == "yes"} {debug_trace "sysdflt2.tcl : before pltfrm test"}

# Each column has two attributes, its position from the left of the
# display (.offset) and its width (.size). These have been configured
# for the optimim settings on each platform.

if {$pltfrm == "windows" || $pltfrm == "windows32"} {
if {$sdlog == "yes"} {debug_trace "sysdflt2.tcl : colman $pltfrm"}
option -default desktop.colman.folder.Group.Count.offset "198"
option -default desktop.colman.folder.Group.Count.size "339"
option -default desktop.colman.folder.Group.Icon.offset "0"
option -default desktop.colman.folder.Group.Icon.size "28"
option -default desktop.colman.folder.Group.Name.offset "28"
option -default desktop.colman.folder.Group.Name.size "170"
option -default desktop.colman.folder.Message.Date.offset "377"
option -default desktop.colman.folder.Message.Date.size "90"
option -default desktop.colman.folder.Message.From.offset "27"
option -default desktop.colman.folder.Message.From.size "150"
option -default desktop.colman.folder.Message.Icon.offset "0"
option -default desktop.colman.folder.Message.Icon.size "27"
option -default desktop.colman.folder.Message.Size.offset "467"
option -default desktop.colman.folder.Message.Size.size "54"
option -default desktop.colman.folder.Message.Subject.offset "177"
option -default desktop.colman.folder.Message.Subject.size "200"
option -default desktop.colman.msgservice.Folder.Count.offset "178"
option -default desktop.colman.msgservice.Folder.Count.size "150"
option -default desktop.colman.msgservice.Folder.Icon.offset "0"
option -default desktop.colman.msgservice.Folder.Icon.size "28"
option -default desktop.colman.msgservice.Folder.Name.offset "28"
option -default desktop.colman.msgservice.Folder.Name.size "150"
option -default desktop.colman.msgservice.Folder.RO.offset "328"
option -default desktop.colman.msgservice.Folder.RO.size "83"
option -default desktop.colman.msgservice.Group.Count.offset "198"
option -default desktop.colman.msgservice.Group.Count.size "346"
option -default desktop.colman.msgservice.Group.Icon.offset "0"
option -default desktop.colman.msgservice.Group.Icon.size "28"
option -default desktop.colman.msgservice.Group.Name.offset "28"
option -default desktop.colman.msgservice.Group.Name.size "170"
option -default desktop.colman.msgservice.Message.Date.offset "377"
option -default desktop.colman.msgservice.Message.Date.size "90"
option -default desktop.colman.msgservice.Message.From.offset "27"
option -default desktop.colman.msgservice.Message.From.size "150"
option -default desktop.colman.msgservice.Message.Icon.offset "0"
option -default desktop.colman.msgservice.Message.Icon.size "27"
option -default desktop.colman.msgservice.Message.Size.offset "467"
option -default desktop.colman.msgservice.Message.Size.size "56"
option -default desktop.colman.msgservice.Message.Subject.offset "177"
option -default desktop.colman.msgservice.Message.Subject.size "200"
option -default desktop.colman.topms.Folder.Count.offset "178"
option -default desktop.colman.topms.Folder.Count.size "150"
option -default desktop.colman.topms.Folder.Icon.offset "0"
option -default desktop.colman.topms.Folder.Icon.size "28"
option -default desktop.colman.topms.Folder.Name.offset "28"
option -default desktop.colman.topms.Folder.Name.size "150"
option -default desktop.colman.topms.Folder.RO.offset "328"
option -default desktop.colman.topms.Folder.RO.size "83"
option -default desktop.colman.topms.Group.Count.offset "198"
option -default desktop.colman.topms.Group.Count.size "348"
option -default desktop.colman.topms.Group.Icon.offset "0"
option -default desktop.colman.topms.Group.Icon.size "28"
option -default desktop.colman.topms.Group.Name.offset "28"
option -default desktop.colman.topms.Group.Name.size "170"
option -default desktop.colman.topms.Message.Date.offset "377"
option -default desktop.colman.topms.Message.Date.size "90"
option -default desktop.colman.topms.Message.From.offset "27"
option -default desktop.colman.topms.Message.From.size "150"
option -default desktop.colman.topms.Message.Icon.offset "0"
option -default desktop.colman.topms.Message.Icon.size "27"
option -default desktop.colman.topms.Message.Size.offset "467"
option -default desktop.colman.topms.Message.Size.size "52"
option -default desktop.colman.topms.Message.Subject.offset "177"
option -default desktop.colman.topms.Message.Subject.size "200"
option -default desktop.colman.topms.MsgService.Icon.offset "0"
option -default desktop.colman.topms.MsgService.Icon.size "32"
option -default desktop.colman.topms.MsgService.Name.offset "32"
option -default desktop.colman.topms.MsgService.Name.size "170"
} elseif {$pltfrm == "mac"} {
if {$sdlog == "yes"} {debug_trace "sysdflt2.tcl : colman $pltfrm"}
option -default desktop.colman.folder.Group.Count.offset "151"
option -default desktop.colman.folder.Group.Count.size "170"
option -default desktop.colman.folder.Group.Icon.offset "0"
option -default desktop.colman.folder.Group.Icon.size "33"
option -default desktop.colman.folder.Group.Name.offset "33"
option -default desktop.colman.folder.Group.Name.size "118"
option -default desktop.colman.folder.Message.Date.offset "277"
option -default desktop.colman.folder.Message.Date.size "85"
option -default desktop.colman.folder.Message.From.offset "35"
option -default desktop.colman.folder.Message.From.size "90"
option -default desktop.colman.folder.Message.Icon.offset "4"
option -default desktop.colman.folder.Message.Icon.size "31"
option -default desktop.colman.folder.Message.Size.offset "362"
option -default desktop.colman.folder.Message.Size.size "40"
option -default desktop.colman.folder.Message.Subject.offset "125"
option -default desktop.colman.folder.Message.Subject.size "152"
option -default desktop.colman.topms.Folder.Count.offset "128"
option -default desktop.colman.topms.Folder.Count.size "205"
option -default desktop.colman.topms.Folder.Icon.offset "0"
option -default desktop.colman.topms.Folder.Icon.size "29"
option -default desktop.colman.topms.Folder.Name.offset "29"
option -default desktop.colman.topms.Folder.Name.size "99"
option -default desktop.colman.topms.Folder.RO.offset "333"
option -default desktop.colman.topms.Folder.RO.size "71"
option -default desktop.colman.topms.Group.Count.offset "148"
option -default desktop.colman.topms.Group.Count.size "170"
option -default desktop.colman.topms.Group.Icon.offset "0"
option -default desktop.colman.topms.Group.Icon.size "29"
option -default desktop.colman.topms.Group.Name.offset "29"
option -default desktop.colman.topms.Group.Name.size "119"
option -default desktop.colman.topms.Message.Date.offset "272"
option -default desktop.colman.topms.Message.Date.size "81"
option -default desktop.colman.topms.Message.From.offset "29"
option -default desktop.colman.topms.Message.From.size "92"
option -default desktop.colman.topms.Message.Icon.offset "0"
option -default desktop.colman.topms.Message.Icon.size "29"
option -default desktop.colman.topms.Message.Size.offset "353"
option -default desktop.colman.topms.Message.Size.size "40"
option -default desktop.colman.topms.Message.Subject.offset "121"
option -default desktop.colman.topms.Message.Subject.size "151"
option -default desktop.colman.topms.MsgService.Icon.offset "0"
option -default desktop.colman.topms.MsgService.Icon.size "34"
option -default desktop.colman.topms.MsgService.Name.offset "34"
option -default desktop.colman.topms.MsgService.Name.size "170"
option -default desktop.colman.msgservice.Folder.Count.offset "128"
option -default desktop.colman.msgservice.Folder.Count.size "205"
option -default desktop.colman.msgservice.Folder.Icon.offset "0"
option -default desktop.colman.msgservice.Folder.Icon.size "29"
option -default desktop.colman.msgservice.Folder.Name.offset "29"
option -default desktop.colman.msgservice.Folder.Name.size "99"
option -default desktop.colman.msgservice.Folder.RO.offset "333"
option -default desktop.colman.msgservice.Folder.RO.size "71"
option -default desktop.colman.msgservice.Group.Count.offset "148"
option -default desktop.colman.msgservice.Group.Count.size "170"
option -default desktop.colman.msgservice.Group.Icon.offset "0"
option -default desktop.colman.msgservice.Group.Icon.size "29"
option -default desktop.colman.msgservice.Group.Name.offset "29"
option -default desktop.colman.msgservice.Group.Name.size "119"
option -default desktop.colman.msgservice.Message.Date.offset "272"
option -default desktop.colman.msgservice.Message.Date.size "71"
option -default desktop.colman.msgservice.Message.From.offset "29"
option -default desktop.colman.msgservice.Message.From.size "92"
option -default desktop.colman.msgservice.Message.Icon.offset "0"
option -default desktop.colman.msgservice.Message.Icon.size "29"
option -default desktop.colman.msgservice.Message.Size.offset "343"
option -default desktop.colman.msgservice.Message.Size.size "40"
option -default desktop.colman.msgservice.Message.Subject.offset "121"
option -default desktop.colman.msgservice.Message.Subject.size "151"
} else {
if {$sdlog == "yes"} {debug_trace "sysdflt2.tcl : colman $pltfrm"}
option -default desktop.colman.folder.Group.Count.offset "198"
option -default desktop.colman.folder.Group.Count.size "366"
option -default desktop.colman.folder.Group.Icon.offset "0"
option -default desktop.colman.folder.Group.Icon.size "28"
option -default desktop.colman.folder.Group.Name.offset "28"
option -default desktop.colman.folder.Group.Name.size "170"
option -default desktop.colman.folder.Message.Date.offset "377"
option -default desktop.colman.folder.Message.Date.size "90"
option -default desktop.colman.folder.Message.From.offset "27"
option -default desktop.colman.folder.Message.From.size "150"
option -default desktop.colman.folder.Message.Icon.offset "0"
option -default desktop.colman.folder.Message.Icon.size "27"
option -default desktop.colman.folder.Message.Size.offset "467"
option -default desktop.colman.folder.Message.Size.size "40"
option -default desktop.colman.folder.Message.Subject.offset "177"
option -default desktop.colman.folder.Message.Subject.size "200"
option -default desktop.colman.msgservice.Folder.Count.offset "178"
option -default desktop.colman.msgservice.Folder.Count.size "150"
option -default desktop.colman.msgservice.Folder.Icon.offset "0"
option -default desktop.colman.msgservice.Folder.Icon.size "28"
option -default desktop.colman.msgservice.Folder.Name.offset "28"
option -default desktop.colman.msgservice.Folder.Name.size "150"
option -default desktop.colman.msgservice.Folder.RO.offset "328"
option -default desktop.colman.msgservice.Folder.RO.size "63"
option -default desktop.colman.msgservice.Group.Count.offset "198"
option -default desktop.colman.msgservice.Group.Count.size "335"
option -default desktop.colman.msgservice.Group.Icon.offset "0"
option -default desktop.colman.msgservice.Group.Icon.size "28"
option -default desktop.colman.msgservice.Group.Name.offset "28"
option -default desktop.colman.msgservice.Group.Name.size "170"
option -default desktop.colman.msgservice.Message.Date.offset "377"
option -default desktop.colman.msgservice.Message.Date.size "90"
option -default desktop.colman.msgservice.Message.From.offset "27"
option -default desktop.colman.msgservice.Message.From.size "150"
option -default desktop.colman.msgservice.Message.Icon.offset "0"
option -default desktop.colman.msgservice.Message.Icon.size "27"
option -default desktop.colman.msgservice.Message.Size.offset "467"
option -default desktop.colman.msgservice.Message.Size.size "40"
option -default desktop.colman.msgservice.Message.Subject.offset "177"
option -default desktop.colman.msgservice.Message.Subject.size "200"
option -default desktop.colman.topms.Folder.Count.offset "178"
option -default desktop.colman.topms.Folder.Count.size "150"
option -default desktop.colman.topms.Folder.Icon.offset "0"
option -default desktop.colman.topms.Folder.Icon.size "28"
option -default desktop.colman.topms.Folder.Name.offset "28"
option -default desktop.colman.topms.Folder.Name.size "150"
option -default desktop.colman.topms.Folder.RO.offset "328"
option -default desktop.colman.topms.Folder.RO.size "63"
option -default desktop.colman.topms.Group.Count.offset "198"
option -default desktop.colman.topms.Group.Count.size "366"
option -default desktop.colman.topms.Group.Icon.offset "0"
option -default desktop.colman.topms.Group.Icon.size "28"
option -default desktop.colman.topms.Group.Name.offset "28"
option -default desktop.colman.topms.Group.Name.size "170"
option -default desktop.colman.topms.Message.Date.offset "377"
option -default desktop.colman.topms.Message.Date.size "90"
option -default desktop.colman.topms.Message.From.offset "27"
option -default desktop.colman.topms.Message.From.size "150"
option -default desktop.colman.topms.Message.Icon.offset "0"
option -default desktop.colman.topms.Message.Icon.size "27"
option -default desktop.colman.topms.Message.Size.offset "467"
option -default desktop.colman.topms.Message.Size.size "40"
option -default desktop.colman.topms.Message.Subject.offset "177"
option -default desktop.colman.topms.Message.Subject.size "200"
option -default desktop.colman.topms.MsgService.Icon.offset "0"
option -default desktop.colman.topms.MsgService.Icon.size "32"
option -default desktop.colman.topms.MsgService.Name.offset "32"
option -default desktop.colman.topms.MsgService.Name.size "170"
}
if {$sdlog == "yes"} {debug_trace "sysdflt2.tcl : END COLUMN MANAGER"}

# END COLUMN MANAGER

if {$sdlog == "yes"} {debug_trace "sysdflt2.tcl end"}

} else {
# There is no sysdflt_version variable defined, therefore the sysdflt.tcl
# file must be from an earlier version. We do not read this file in this
# situation because we may overwrite the helper apps and desktop settings
# which are in sysdflt.tcl in earlier versions.

debug_trace "sysdflt2.tcl : sysdflt2.tcl not read, sysdflt.tcl file from 4.1.1 or earlier."
}

# END MODULE : site_administration_defaults - All platforms, part 2

